[![CI](https://github.com/bihealth/clinvar-this/actions/workflows/main.yml/badge.svg?branch=main)](https://github.com/bihealth/clinvar-this/actions/workflows/main.yml)
[![codecov](https://codecov.io/gh/bihealth/clinvar-this/branch/main/graph/badge.svg?token=059T45KAQM)](https://codecov.io/gh/bihealth/clinvar-this)
[![Documentation Status](https://readthedocs.org/projects/clinvar-this/badge/?version=latest)](https://clinvar-this.readthedocs.io/en/latest/?badge=latest)
[![Bioconda](https://img.shields.io/conda/dn/bioconda/clinvar-this.svg?label=Bioconda)](https://bioconda.github.io/recipes/clinvar-this/README.html)
[![Pypi](https://img.shields.io/pypi/pyversions/clinvar-this.svg)](https://pypi.org/project/clinvar-this)

# ClinVar This!

ClinVar Submission via API Made Easy

- Free software: MIT license
- Documentation: https://clinvar-this.readthedocs.io/en/latest/
- Discussion Forum: https://github.com/bihealth/clinvar-this/discussions
- Bug Reports: https://github.com/bihealth/clinvar-this/issues

## Getting Started

![The clinvar-this workflow](docs/figures/clinvar-this-workflow.png)

## Documentation

You can find comprehensive documentation here:

- https://clinvar-this.readthedocs.io/en/latest/

A good place to start is:

- ["Getting Started" in the documentation](https://clinvar-this.readthedocs.io/en/latest/getting_started.html)
